@@ -8,7 +8,10 @@ from botorch.acquisition.acquisition import (
     AcquisitionFunction,
     OneShotAcquisitionFunction,
 )
-from botorch.acquisition.active_learning import qNegIntegratedPosteriorVariance
+from botorch.acquisition.active_learning import (
+    PairwiseMCPosteriorVariance,
+    qNegIntegratedPosteriorVariance,
+)
 from botorch.acquisition.analytic import (
     AnalyticAcquisitionFunction,
     ConstrainedExpectedImprovement,
@@ -32,6 +35,7 @@ from botorch.acquisition.max_value_entropy_search import (
     MaxValueBase,
     qLowerBoundMaxValueEntropy,
     qMaxValueEntropy,
+    qMultiFidelityLowerBoundMaxValueEntropy,
     qMultiFidelityMaxValueEntropy,
 )
 from botorch.acquisition.monte_carlo import (
@@ -47,17 +51,20 @@ from botorch.acquisition.objective import (
     ConstrainedMCObjective,
     GenericMCObjective,
     IdentityMCObjective,
+    LearnedObjective,
     LinearMCObjective,
     MCAcquisitionObjective,
     ScalarizedObjective,
     ScalarizedPosteriorTransform,
 )
+from botorch.acquisition.preference import AnalyticExpectedUtilityOfBestOption
 from botorch.acquisition.proximal import ProximalAcquisitionFunction
 from botorch.acquisition.utils import get_acquisition_function
 
 __all__ = [
     "AcquisitionFunction",
     "AnalyticAcquisitionFunction",
+    "AnalyticExpectedUtilityOfBestOption",
     "ConstrainedExpectedImprovement",
     "ExpectedImprovement",
     "FixedFeatureAcquisitionFunction",
@@ -65,6 +72,7 @@ __all__ = [
     "InverseCostWeightedUtility",
     "NoisyExpectedImprovement",
     "OneShotAcquisitionFunction",
+    "PairwiseMCPosteriorVariance",
     "PosteriorMean",
     "ProbabilityOfImprovement",
     "ProximalAcquisitionFunction",
@@ -74,6 +82,7 @@ __all__ = [
     "MaxValueBase",
     "qMultiFidelityKnowledgeGradient",
     "qMaxValueEntropy",
+    "qMultiFidelityLowerBoundMaxValueEntropy",
     "qLowerBoundMaxValueEntropy",
     "qMultiFidelityMaxValueEntropy",
     "qMultiStepLookahead",
@@ -85,6 +94,7 @@ __all__ = [
     "ConstrainedMCObjective",
     "GenericMCObjective",
     "IdentityMCObjective",
+    "LearnedObjective",
     "LinearMCObjective",
     "MCAcquisitionFunction",
     "MCAcquisitionObjective",
