@@ -30,9 +30,7 @@ from itertools import combinations
 from typing import Any, Callable, List, Optional, Union
 
 import torch
-from botorch.acquisition.acquisition import (
-    AcquisitionFunction,
-)
+from botorch.acquisition.acquisition import AcquisitionFunction
 from botorch.acquisition.cached_cholesky import CachedCholeskyMCAcquisitionFunction
 from botorch.acquisition.multi_objective.objective import (
     IdentityMCMultiOutputObjective,
@@ -65,6 +63,7 @@ from botorch.utils.objective import apply_constraints_nonnegative_soft
 from botorch.utils.torch import BufferDict
 from botorch.utils.transforms import (
     concatenate_pending_points,
+    is_fully_bayesian,
     match_batch_shape,
     t_batch_mode_transform,
 )
@@ -742,8 +741,10 @@ class qNoisyExpectedHypervolumeImprovement(
         # TODO: improve efficiency by not recomputing baseline-baseline
         # covariance matrix.
         posterior = self.model.posterior(X_full)
-        # Account for possible one-to-many transform.
-        n_w = posterior.event_shape[X_full.dim() - 2] // X_full.shape[-2]
+        # Account for possible one-to-many transform and the MCMC batch dimension in
+        # `SaasFullyBayesianSingleTaskGP`
+        event_shape_lag = 1 if is_fully_bayesian(self.model) else 2
+        n_w = posterior.event_shape[X_full.dim() - event_shape_lag] // X_full.shape[-2]
         q_in = X.shape[-2] * n_w
         self._set_sampler(q_in=q_in, posterior=posterior)
         samples = self._get_f_X_samples(posterior=posterior, q_in=q_in)
