@@ -38,6 +38,7 @@ from botorch.acquisition.multi_objective.objective import (
 )
 from botorch.acquisition.risk_measures import CVaR, RiskMeasureMCObjective, VaR
 from botorch.exceptions.errors import UnsupportedError
+from botorch.exceptions.warnings import BotorchWarning
 from botorch.models.model import Model
 from botorch.utils.multi_objective.pareto import is_non_dominated
 from botorch.utils.transforms import normalize
@@ -54,6 +55,8 @@ class MultiOutputRiskMeasureMCObjective(
     If the q-batch includes samples corresponding to multiple inputs, it is assumed
     that first `n_w` samples correspond to first input, second `n_w` samples
     correspond to second input, etc.
+
+    :meta private:
     """
 
     def __init__(
@@ -503,7 +506,7 @@ class MVaR(MultiOutputRiskMeasureMCObjective):
             if self.expectation:
                 padded_mvar_list.append(mvar_.mean(dim=0))
             else:
-                # Repeat the last entry to make `mvar_set` `n_w x m`.
+                # Repeat the last entry to make `mvar_set` `pad_size x m`.
                 repeats_needed = pad_size - mvar_.shape[0]
                 padded_mvar_list.append(
                     torch.cat([mvar_, mvar_[-1].expand(repeats_needed, m)], dim=0)
@@ -555,7 +558,7 @@ class MARS(VaR, MultiOutputRiskMeasureMCObjective):
                 apply feasibility-weighting to samples.
         """
         super().__init__(alpha=alpha, n_w=n_w)
-        self.chebyshev_weights = chebyshev_weights
+        self.chebyshev_weights = torch.as_tensor(chebyshev_weights)
         self.baseline_Y = baseline_Y
         self.register_buffer(
             "ref_point", torch.as_tensor(ref_point) if ref_point is not None else None
@@ -566,17 +569,34 @@ class MARS(VaR, MultiOutputRiskMeasureMCObjective):
         self.mvar = MVaR(n_w=self.n_w, alpha=self.alpha)
         self._chebyshev_objective = None
 
-    def set_baseline_Y(self, model: Model, X_baseline: Tensor) -> None:
+    def set_baseline_Y(
+        self,
+        model: Optional[Model],
+        X_baseline: Optional[Tensor],
+        Y_samples: Optional[Tensor] = None,
+    ) -> None:
         r"""Set the `baseline_Y` based on the MVaR predictions of the `model`
         for `X_baseline`.
 
         Args:
             model: The model being used for MARS optimization. Must have a compatible
-                `InputPerturbation` transform attached.
+                `InputPerturbation` transform attached. Ignored if `Y_samples` is given.
             X_baseline: An `n x d`-dim tensor of previously evaluated points.
+                Ignored if `Y_samples` is given.
+            Y_samples: An optional `(n * n_w) x d`-dim tensor of predictions. If given,
+                instead of sampling from the model, these are used.
         """
-        with torch.no_grad():
-            Y = model.posterior(X_baseline).mean
+        if Y_samples is None:
+            with torch.no_grad():
+                Y = model.posterior(X_baseline.unsqueeze(-2)).mean.squeeze(-2)
+        else:
+            if model is not None or X_baseline is not None:
+                warnings.warn(
+                    "`model` and `X_baseline` are ignored when `Y_samples` is "
+                    "provided to `MARS.set_baseline_Y`.",
+                    BotorchWarning,
+                )
+            Y = Y_samples
         Y = self.preprocessing_function(Y)
         Y = self.mvar(Y).view(-1, Y.shape[-1])
         Y = Y[is_non_dominated(Y)]
@@ -659,7 +679,7 @@ class MARS(VaR, MultiOutputRiskMeasureMCObjective):
             Y = normalize(Y, bounds=Y_bounds)
             if ref_point is not None:
                 Y = Y - ref_point
-            product = torch.einsum("...m,m->...m", Y, self.chebyshev_weights)
+            product = torch.einsum("...m,m->...m", Y, self.chebyshev_weights.to(Y))
             return product.min(dim=-1).values
 
         self._chebyshev_objective = chebyshev_obj
